pub enum Error {
NotAbsolute,
NotCanonical,
ContainsParent,
}Expand description
The error type indicating why a path cannot be a valid Normpath.
Notes on Windows
On Windows, a parent directory component that can be normalized away (e.g.
C:\foo\..) is not considered as ContainsParent, but instead as
NotCanonical.
See crate documentation for more details about that.
Variants
NotAbsolute
The path is not absolute.
NotCanonical
The path is not canonical.
ContainsParent
The path contains a parent component that cannot be normalized away.