pub struct ConvertError<T> {
pub error: Error,
pub value: T,
}Expand description
The error type indicating why a path cannot be converted into a normalized path.
This type is essentially an Error plus the original value.
Fields
error: ErrorThe error indicating why the conversion failed.
value: TThe value that failed to convert.
Implementations
Sourceimpl<T> ConvertError<T>
impl<T> ConvertError<T>
Sourceimpl<T: ?Sized> ConvertError<&T>
impl<T: ?Sized> ConvertError<&T>
Sourcepub fn cloned(&self) -> ConvertError<T>where
T: Clone,
pub fn cloned(&self) -> ConvertError<T>where
T: Clone,
Clones the value, without changing the underlying error.
Sourcepub fn to_owned(&self) -> ConvertError<T::Owned>where
T: ToOwned,
pub fn to_owned(&self) -> ConvertError<T::Owned>where
T: ToOwned,
Converts the value into an owned version, without changing the underlying error.